@@ -1,8 +1,8 @@
 import unittest
 import tkinter
 from tkinter import font
-from test.support import requires, gc_collect, ALWAYS_EQ
-from tkinter.test.support import AbstractTkTest, AbstractDefaultRootTest
+from test.support import requires, run_unittest
+from tkinter.test.support import AbstractTkTest
 
 requires('gui')
 
@@ -35,16 +35,6 @@ class FontTest(AbstractTkTest, unittest.TestCase):
             self.assertIsInstance(self.font.cget(key), sizetype)
             self.assertIsInstance(self.font[key], sizetype)
 
-    def test_unicode_family(self):
-        family = 'MS \u30b4\u30b7\u30c3\u30af'
-        try:
-            f = font.Font(root=self.root, family=family, exists=True)
-        except tkinter.TclError:
-            f = font.Font(root=self.root, family=family, exists=False)
-        self.assertEqual(f.cget('family'), family)
-        del f
-        gc_collect()
-
     def test_actual(self):
         options = self.font.actual()
         self.assertGreaterEqual(set(options),
@@ -63,21 +53,13 @@ class FontTest(AbstractTkTest, unittest.TestCase):
         self.assertEqual(self.font.name, fontname)
         self.assertEqual(str(self.font), fontname)
 
-    def test_equality(self):
+    def test_eq(self):
         font1 = font.Font(root=self.root, name=fontname, exists=True)
         font2 = font.Font(root=self.root, name=fontname, exists=True)
         self.assertIsNot(font1, font2)
         self.assertEqual(font1, font2)
         self.assertNotEqual(font1, font1.copy())
-
         self.assertNotEqual(font1, 0)
-        self.assertEqual(font1, ALWAYS_EQ)
-
-        root2 = tkinter.Tk()
-        self.addCleanup(root2.destroy)
-        font3 = font.Font(root=root2, name=fontname, exists=True)
-        self.assertEqual(str(font1), str(font3))
-        self.assertNotEqual(font1, font3)
 
     def test_measure(self):
         self.assertIsInstance(self.font.measure('abc'), int)
@@ -108,36 +90,7 @@ class FontTest(AbstractTkTest, unittest.TestCase):
             self.assertTrue(name)
         self.assertIn(fontname, names)
 
-
-class DefaultRootTest(AbstractDefaultRootTest, unittest.TestCase):
-
-    def test_families(self):
-        self.assertRaises(RuntimeError, font.families)
-        root = tkinter.Tk()
-        families = font.families()
-        self.assertIsInstance(families, tuple)
-        self.assertTrue(families)
-        for family in families:
-            self.assertIsInstance(family, str)
-            self.assertTrue(family)
-        root.destroy()
-        tkinter.NoDefaultRoot()
-        self.assertRaises(RuntimeError, font.families)
-
-    def test_names(self):
-        self.assertRaises(RuntimeError, font.names)
-        root = tkinter.Tk()
-        names = font.names()
-        self.assertIsInstance(names, tuple)
-        self.assertTrue(names)
-        for name in names:
-            self.assertIsInstance(name, str)
-            self.assertTrue(name)
-        self.assertIn(fontname, names)
-        root.destroy()
-        tkinter.NoDefaultRoot()
-        self.assertRaises(RuntimeError, font.names)
-
+tests_gui = (FontTest, )
 
 if __name__ == "__main__":
-    unittest.main()
+    run_unittest(*tests_gui)
