@@ -20,7 +20,6 @@ import shutil
 import subprocess
 import sys
 import tempfile
-import test.support
 import unittest
 
 # Local imports
@@ -85,16 +84,12 @@ class TestPgen2Caching(support.TestCase):
             # different hash randomization seed.
             sub_env = dict(os.environ)
             sub_env['PYTHONHASHSEED'] = 'random'
-            code = """
+            subprocess.check_call(
+                    [sys.executable, '-c', """
 from lib2to3.pgen2 import driver as pgen2_driver
 pgen2_driver.load_grammar(%r, save=True, force=True)
-            """ % (grammar_sub_copy,)
-            msg = ("lib2to3 package is deprecated and may not be able "
-                   "to parse Python 3.10+")
-            cmd = [sys.executable,
-                   f'-Wignore:{msg}:PendingDeprecationWarning',
-                   '-c', code]
-            subprocess.check_call( cmd, env=sub_env)
+                    """ % (grammar_sub_copy,)],
+                    env=sub_env)
             self.assertTrue(os.path.exists(pickle_sub_name))
 
             with open(pickle_name, 'rb') as pickle_f_1, \
@@ -201,27 +196,20 @@ class TestAsyncAwait(GrammarTest):
         self.validate("""await = 1""")
         self.validate("""def async(): pass""")
 
-    def test_async_for(self):
+    def test_async_with(self):
         self.validate("""async def foo():
                              async for a in b: pass""")
 
-    def test_async_with(self):
+        self.invalid_syntax("""def foo():
+                                   async for a in b: pass""")
+
+    def test_async_for(self):
         self.validate("""async def foo():
                              async with a: pass""")
 
         self.invalid_syntax("""def foo():
                                    async with a: pass""")
 
-    def test_async_generator(self):
-        self.validate(
-            """async def foo():
-                   return (i * 2 async for i in arange(42))"""
-        )
-        self.validate(
-            """def foo():
-                   return (i * 2 async for i in arange(42))"""
-        )
-
 
 class TestRaiseChanges(GrammarTest):
     def test_2x_style_1(self):
@@ -284,12 +272,6 @@ class TestUnpackingGeneralizations(GrammarTest):
     def test_dict_display_2(self):
         self.validate("""{**{}, 3:4, **{5:6, 7:8}}""")
 
-    def test_complex_star_expression(self):
-        self.validate("func(* [] or [1])")
-
-    def test_complex_double_star_expression(self):
-        self.validate("func(**{1: 3} if False else {x: x for x in range(3)})")
-
     def test_argument_unpacking_1(self):
         self.validate("""f(a, *b, *c, d)""")
 
@@ -556,7 +538,7 @@ class TestSetLiteral(GrammarTest):
 
 # Adapted from Python 3's Lib/test/test_unicode_identifiers.py and
 # Lib/test/test_tokenize.py:TokenizeTest.test_non_ascii_identifiers
-class TestIdentifier(GrammarTest):
+class TestIdentfier(GrammarTest):
     def test_non_ascii_identifiers(self):
         self.validate("Örter = 'places'\ngrün = 'green'")
         self.validate("蟒 = a蟒 = 锦蛇 = 1")
@@ -587,31 +569,25 @@ class TestParserIdempotency(support.TestCase):
 
     """A cut-down version of pytree_idempotency.py."""
 
-    def parse_file(self, filepath):
-        if test.support.verbose:
-            print(f"Parse file: {filepath}")
-        with open(filepath, "rb") as fp:
-            encoding = tokenize.detect_encoding(fp.readline)[0]
-        self.assertIsNotNone(encoding,
-                             "can't detect encoding for %s" % filepath)
-        with open(filepath, "r", encoding=encoding) as fp:
-            source = fp.read()
-        try:
-            tree = driver.parse_string(source)
-        except ParseError:
-            try:
-                tree = driver_no_print_statement.parse_string(source)
-            except ParseError as err:
-                self.fail('ParseError on file %s (%s)' % (filepath, err))
-        new = str(tree)
-        if new != source:
-            print(diff_texts(source, new, filepath))
-            self.fail("Idempotency failed: %s" % filepath)
-
     def test_all_project_files(self):
         for filepath in support.all_project_files():
-            with self.subTest(filepath=filepath):
-                self.parse_file(filepath)
+            with open(filepath, "rb") as fp:
+                encoding = tokenize.detect_encoding(fp.readline)[0]
+            self.assertIsNotNone(encoding,
+                                 "can't detect encoding for %s" % filepath)
+            with open(filepath, "r", encoding=encoding) as fp:
+                source = fp.read()
+            try:
+                tree = driver.parse_string(source)
+            except ParseError:
+                try:
+                    tree = driver_no_print_statement.parse_string(source)
+                except ParseError as err:
+                    self.fail('ParseError on file %s (%s)' % (filepath, err))
+            new = str(tree)
+            if new != source:
+                print(diff_texts(source, new, filepath))
+                self.fail("Idempotency failed: %s" % filepath)
 
     def test_extended_unpacking(self):
         driver.parse_string("a, *b, c = x\n")
@@ -654,7 +630,6 @@ class TestLiterals(GrammarTest):
 
 
 class TestNamedAssignments(GrammarTest):
-    """Also known as the walrus operator."""
 
     def test_named_assignment_if(self):
         driver.parse_string("if f := x(): pass\n")
@@ -669,42 +644,6 @@ class TestNamedAssignments(GrammarTest):
         driver.parse_string("[(lastNum := num) == 1 for num in [1, 2, 3]]\n")
 
 
-class TestPositionalOnlyArgs(GrammarTest):
-
-    def test_one_pos_only_arg(self):
-        driver.parse_string("def one_pos_only_arg(a, /): pass\n")
-
-    def test_all_markers(self):
-        driver.parse_string(
-                "def all_markers(a, b=2, /, c, d=4, *, e=5, f): pass\n")
-
-    def test_all_with_args_and_kwargs(self):
-        driver.parse_string(
-                """def all_markers_with_args_and_kwargs(
-                           aa, b, /, _cc, d, *args, e, f_f, **kwargs,
-                   ):
-                       pass\n""")
-
-    def test_lambda_soup(self):
-        driver.parse_string(
-                "lambda a, b, /, c, d, *args, e, f, **kw: kw\n")
-
-    def test_only_positional_or_keyword(self):
-        driver.parse_string("def func(a,b,/,*,g,e=3): pass\n")
-
-
-class TestPickleableException(unittest.TestCase):
-    def test_ParseError(self):
-        err = ParseError('msg', 2, None, (1, 'context'))
-        for proto in range(pickle.HIGHEST_PROTOCOL + 1):
-            err2 = pickle.loads(pickle.dumps(err, protocol=proto))
-            self.assertEqual(err.args, err2.args)
-            self.assertEqual(err.msg, err2.msg)
-            self.assertEqual(err.type, err2.type)
-            self.assertEqual(err.value, err2.value)
-            self.assertEqual(err.context, err2.context)
-
-
 def diff_texts(a, b, filename):
     a = a.splitlines()
     b = b.splitlines()
