@@ -17,8 +17,7 @@ from distutils.errors import DistutilsOptionError
 
 from site import USER_BASE
 from site import USER_SITE
-
-HAS_USER_SITE = (USER_SITE is not None)
+HAS_USER_SITE = True
 
 WINDOWS_SCHEME = {
     'purelib': '$base/Lib/site-packages',
@@ -170,9 +169,8 @@ class install(Command):
         self.install_lib = None         # set to either purelib or platlib
         self.install_scripts = None
         self.install_data = None
-        if HAS_USER_SITE:
-            self.install_userbase = USER_BASE
-            self.install_usersite = USER_SITE
+        self.install_userbase = USER_BASE
+        self.install_usersite = USER_SITE
 
         self.compile = None
         self.optimize = None
@@ -345,9 +343,8 @@ class install(Command):
         # Convert directories from Unix /-separated syntax to the local
         # convention.
         self.convert_paths('lib', 'purelib', 'platlib',
-                           'scripts', 'data', 'headers')
-        if HAS_USER_SITE:
-            self.convert_paths('userbase', 'usersite')
+                           'scripts', 'data', 'headers',
+                           'userbase', 'usersite')
 
         # Deprecated
         # Well, we're not actually fully completely finalized yet: we still
